@@ -1,11 +1,11 @@
-from .types import t_static
+from .types import t_asset
 from .manager import Manager
 import os
 
 
 class Assets:
     naas = None
-    role = t_static
+    role = t_asset
 
     def __init__(self):
         self.manager = Manager()
@@ -21,7 +21,7 @@ class Assets:
         for item in json_data:
             kind = None
             if item["type"] == self.role:
-                kind = f"publicly gettable with this url {self.manager.proxy_url('static', item['value'])}"
+                kind = f"publicly gettable with this url {self.manager.proxy_url('assets', item['value'])}"
                 print(f"File ==> {item['path']} is {kind}")
 
     def get(self, path=None):
@@ -48,6 +48,7 @@ class Assets:
             return
         current_file = self.manager.get_path(path)
         self.manager.clear_history(current_file, histo)
+        print("🕣 Your Assets history has been remove from production folder.\n")
 
     def add(self, path=None, params={}, debug=False, Force=False):
         current_file = self.manager.get_path(path)
@@ -58,16 +59,14 @@ class Assets:
         token = self.manager.get_value(prod_path, self.role)
         if token is None or Force is True:
             token = os.urandom(30).hex()
-        url = self.manager.proxy_url("static", token)
+        url = self.manager.proxy_url(self.role, token)
         if not self.manager.notebook_path() and Force is False:
             print("No add done you are in already in naas folder\n")
             return url
         print("👌 Well done! Your Assets has been sent to production folder.\n")
         print(f"🔗 You can access this assets remotely with: {url} \n")
         self.manager.copy_url(url)
-        print(
-            'PS: to remove the "Notebook as API" feature, just replace .add by .delete'
-        )
+        print('PS: to remove the "Assets" feature, just replace .add by .delete')
         self.manager.add_prod(
             {"type": self.role, "path": current_file, "params": params, "value": token},
             not debug,
@@ -80,9 +79,9 @@ class Assets:
             return
         current_file = self.manager.get_path(path)
         self.manager.del_prod({"type": self.role, "path": current_file}, not debug)
+        print("🗑 Done! Your Assets has been remove from production folder.\n")
         if all is True:
             self.manager.clear_history(current_file)
-            self.manager.clear_output(current_file)
 
     def help(self):
         print(f"=== {type(self).__name__} === \n")
