@@ -1,5 +1,16 @@
 from asyncio import Semaphore
-from naas.types import t_delete, t_add, t_skip, t_update, t_error, t_start
+from naas.types import (
+    t_delete,
+    t_add,
+    t_skip,
+    t_update,
+    t_error,
+    t_start,
+    t_notebook,
+    t_asset,
+    t_dependency,
+    t_scheduler,
+)
 import pandas as pd
 import datetime
 import errno
@@ -8,6 +19,9 @@ import os
 import uuid
 
 
+filters = [t_notebook, t_asset, t_dependency, t_scheduler]
+
+
 class Jobs:
     __storage_sem = None
     __path_user_files = None
@@ -16,7 +30,7 @@ class Jobs:
     __naas_folder = ".naas"
     __json_name = "jobs.json"
 
-    def __init__(self, logger, loop, clean=False, init_data=[]):
+    def __init__(self, logger, clean=False, init_data=[]):
         self.__path_user_files = os.environ.get(
             "JUPYTER_SERVER_ROOT", f'/home/{os.environ.get("NB_USER", "ftp")}'
         )
@@ -26,7 +40,7 @@ class Jobs:
         self.__json_secrets_path = os.path.join(
             self.__path_naas_files, self.__json_name
         )
-        self.__storage_sem = Semaphore(1, loop=loop)
+        self.__storage_sem = Semaphore(1)
         self.__logger = logger
         if not os.path.exists(self.__path_naas_files):
             try:
@@ -43,6 +57,7 @@ class Jobs:
             try:
                 print("Init Job Storage", self.__json_secrets_path)
                 self.__save_to_file(uid, init_data)
+                self.__df = None
             except Exception as e:
                 print("Exception", e)
                 self.__logger.error(
@@ -56,6 +71,7 @@ class Jobs:
         else:
             uid = str(uuid.uuid4())
             self.__df = self.__get_save_from_file(uid)
+            self.__cleanup_jobs()
         if self.__df is None or len(self.__df) == 0:
             self.__df = pd.DataFrame(
                 columns=[
@@ -71,6 +87,10 @@ class Jobs:
                 ]
             )
 
+    def __cleanup_jobs(self):
+        if len(self.__df) > 0:
+            self.__df = self.__df[self.__df.type.isin(filters)]
+
     def __get_save_from_file(self, uid):
         data = []
         try:
