@@ -3,17 +3,11 @@ from apscheduler.schedulers.asyncio import AsyncIOScheduler
 import apscheduler.schedulers.base
 import traceback
 import datetime
-
-# import nest_asyncio
 import asyncio
 import pycron
 import time
 import uuid
 
-# TODO remove this fix when papermill support uvloop of Sanic support option to don't use uvloop
-# asyncio.set_event_loop_policy(None)
-# nest_asyncio.apply()
-
 
 class Scheduler:
     __scheduler = None
@@ -47,7 +41,6 @@ class Scheduler:
             self.__logger.info({"id": uid, "type": t_main, "status": "start SCHEDULER"})
 
     async def __scheduler_greenlet(self, main_uid, current_time, task):
-        print("__scheduler_greenlet => start")
         try:
             value = task.get("value", None)
             current_type = task.get("type", None)
@@ -61,7 +54,6 @@ class Scheduler:
                 and pycron.is_now(value, current_time)
                 and not running
             ):
-                print("__scheduler_greenlet => right time")
                 self.__logger.info(
                     {
                         "main_id": str(main_uid),
@@ -116,9 +108,6 @@ class Scheduler:
                     t_health,
                     res.get("duration"),
                 )
-                print("__scheduler_greenlet => runned")
-            else:
-                print("__scheduler_greenlet => NOT runned")
         except:  # noqa: E722
             tb = traceback.format_exc()
             self.__logger.error(
